RestClient

Struct RestClient 

pub struct RestClient {
    pub client: ClientWithMiddleware,
    pub url: Url,
}
A reqwest client (with middleware) and a base url, which can make “REST” (http-json) requests and parse responses according to serde-schema.

All errors retain context about the url, method, and route requested, and at what point in the process the failure occurred.

The RestClient is agnostic about how you initialize ClientWithMiddleware and Url. If you like you may use CommonConfig to setup timeouts and retries on a reqwest::ClientBuilder.

Fields

client: ClientWithMiddleware

The client to use to make requests

url: Url

The base url of the API, to which routes are joined

Implementations

Source

impl RestClient

pub async fn request<S: Serialize, T: DeserializeOwned>( &self, method: Method, route: impl AsRef<str> + Debug, data: &S, ) -> Result<T, Error>

Makes a request for given method, route, and data. If it is a GET request, the data is url encoded as query params, otherwise it becomes json in the request body.

pub async fn request_with_headers<S: Serialize, T: DeserializeOwned>( &self, method: Method, route: impl AsRef<str> + Debug, headers: HeaderMap, data: &S, ) -> Result<T, Error>

Makes a request for given method, route, and data, with given http headers.